"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSimpleQueries = getSimpleQueries;
exports.screen = exports.variants = void 0;

var _react = require("@testing-library/react");

const variants = ['LabelText', 'PlaceholderText', 'Text', 'DisplayValue', 'AltText', 'Title', 'Role', 'TestId']; // was easier to test
// Object.keys(rtlScreen).forEach(queryName => {
//   if (queryName.startsWith('getAllBy')) {
//     const variantName = queryName.replace('getAllBy', '')
//     variants.push(variantName)
//   }
// })

exports.variants = variants;

function getProxySyncMethod(variant, queries, {
  allowMultiple,
  allowEmpty
}) {
  const fnName = `${allowEmpty ? 'query' : 'get'}${allowMultiple ? 'All' : ''}By${variant}`;
  return queries[fnName];
}

function getProxyAsyncMethod(variant, queries, {
  allowMultiple
}) {
  const fnName = `find${allowMultiple ? 'All' : ''}By${variant}`;
  return queries[fnName];
}

function getSimpleQueries(utils) {
  const syncQueries = {};
  const asyncQueries = {};
  variants.forEach(variant => {
    syncQueries[`fetchBy${variant}`] = (matcher, {
      allowMultiple = false,
      allowEmpty = false,
      ...options
    } = {}, ...args) => {
      const fn = getProxySyncMethod(variant, utils, {
        allowMultiple,
        allowEmpty
      });
      return fn(matcher, options, ...args);
    };

    asyncQueries[`fetchBy${variant}Async`] = (matcher, {
      allowMultiple = false,
      ...options
    } = {}, ...args) => {
      const fn = getProxyAsyncMethod(variant, utils, {
        allowMultiple
      });
      return fn(matcher, options, ...args);
    };
  });
  return { ...syncQueries,
    ...asyncQueries
  };
}

const simpleQueries = getSimpleQueries(_react.screen);
const screen = { ..._react.screen,
  ...simpleQueries
};
exports.screen = screen;